# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`syslog_ng`](#syslog_ng): Manage syslog-ng

#### Private Classes

* `syslog_ng::reload`: Manage syslog-ng configuration reloading
* `syslog_ng::repo`: Manage the syslog-ng repository

### Defined types

* [`syslog_ng::config`](#syslog_ng--config): Add raw configuration
* [`syslog_ng::destination`](#syslog_ng--destination): Add a destination
* [`syslog_ng::filter`](#syslog_ng--filter): Add a filter
* [`syslog_ng::log`](#syslog_ng--log): Add a log
* [`syslog_ng::module`](#syslog_ng--module): Install syslog-ng modules
* [`syslog_ng::options`](#syslog_ng--options): Add global options
* [`syslog_ng::parser`](#syslog_ng--parser): Add a parser
* [`syslog_ng::rewrite`](#syslog_ng--rewrite): Add a rewrite rule
* [`syslog_ng::source`](#syslog_ng--source): Add a source
* [`syslog_ng::template`](#syslog_ng--template): Add a template

### Functions

* [`syslog_ng::generate_log`](#syslog_ng--generate_log): Gererate log
* [`syslog_ng::generate_options`](#syslog_ng--generate_options): Generate options
* [`syslog_ng::generate_statement`](#syslog_ng--generate_statement): Generate statement

## Classes

### <a name="syslog_ng"></a>`syslog_ng`

The main class of this module. By including it you get an installed syslog-ng with default configuration on your system.

#### Parameters

The following parameters are available in the `syslog_ng` class:

* [`config_file`](#-syslog_ng--config_file)
* [`package_name`](#-syslog_ng--package_name)
* [`service_name`](#-syslog_ng--service_name)
* [`module_prefix`](#-syslog_ng--module_prefix)
* [`config_file_header`](#-syslog_ng--config_file_header)
* [`package_ensure`](#-syslog_ng--package_ensure)
* [`manage_repo`](#-syslog_ng--manage_repo)
* [`manage_package`](#-syslog_ng--manage_package)
* [`manage_init_defaults`](#-syslog_ng--manage_init_defaults)
* [`modules`](#-syslog_ng--modules)
* [`sbin_path`](#-syslog_ng--sbin_path)
* [`user`](#-syslog_ng--user)
* [`group`](#-syslog_ng--group)
* [`syntax_check_before_reloads`](#-syslog_ng--syntax_check_before_reloads)
* [`init_config_file`](#-syslog_ng--init_config_file)
* [`init_config_hash`](#-syslog_ng--init_config_hash)

##### <a name="-syslog_ng--config_file"></a>`config_file`

Data type: `Stdlib::Absolutepath`

Configures the path of the configuration file.

##### <a name="-syslog_ng--package_name"></a>`package_name`

Data type: `String[1]`

Name of the package to manage when `manage_package` is `true`.

##### <a name="-syslog_ng--service_name"></a>`service_name`

Data type: `String[1]`

Name of the syslog-ng service.

##### <a name="-syslog_ng--module_prefix"></a>`module_prefix`

Data type: `String[1]`

A string to prepend to syslog-ng module names to obtain the corresponding package names.

##### <a name="-syslog_ng--config_file_header"></a>`config_file_header`

Data type: `String[1]`

A header string that appear on top of the syslog-ng configuration.

##### <a name="-syslog_ng--package_ensure"></a>`package_ensure`

Data type: `String[1]`

The value of the `ensure` parameter of package resources.

##### <a name="-syslog_ng--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Controls if the module is managing the unofficial repositories of syslog-ng packages. Use true if you want to use the latest version of syslog-ng from the unofficial Debian repository or unofficial RedHat repository.

Default value: `false`

##### <a name="-syslog_ng--manage_package"></a>`manage_package`

Data type: `Boolean`

Controls if the module is managing the package resource or not. Use false if you are already handling this in your manifests.

Default value: `true`

##### <a name="-syslog_ng--manage_init_defaults"></a>`manage_init_defaults`

Data type: `Boolean`

Controls if the module is managing the init script's config file (See init_config_file and init_config_hash).

Default value: `false`

##### <a name="-syslog_ng--modules"></a>`modules`

Data type: `Array[String[1]]`

Configures additional syslog-ng modules. If `manage_package` is set to `true` this will also install the corresponding packages, *e.g.* `syslog-ng-riemann` on RedHat if `modules = ['riemann']`.

Default value: `[]`

##### <a name="-syslog_ng--sbin_path"></a>`sbin_path`

Data type: `Stdlib::Absolutepath`

Configures the path, where `syslog-ng` and `syslog-ng-ctl` binaries can be found.

Default value: `'/usr/sbin'`

##### <a name="-syslog_ng--user"></a>`user`

Data type: `String[1]`

Configures `syslog-ng` to run as `user`.

Default value: `'root'`

##### <a name="-syslog_ng--group"></a>`group`

Data type: `String[1]`

Configures `syslog-ng` to run as `group`.

Default value: `'root'`

##### <a name="-syslog_ng--syntax_check_before_reloads"></a>`syntax_check_before_reloads`

Data type: `Boolean`

The module always checks the syntax of the generated configuration. If it is not OK, the main configuration (usually /etc/syslog-ng/syslog-ng.conf) will not be overwritten, but you can disable this behavior by setting this parameter to false.

Default value: `true`

##### <a name="-syslog_ng--init_config_file"></a>`init_config_file`

Data type: `Stdlib::Absolutepath`

Path to the init script configuration file.

##### <a name="-syslog_ng--init_config_hash"></a>`init_config_hash`

Data type: `Hash`

Hash of init configuration options to put into `init_config_file`. This has OS specific defaults which will be merged to user specified value.

## Defined types

### <a name="syslog_ng--config"></a>`syslog_ng::config`

Some elements of the syslog-ng DSL are not supported by this module (mostly the boolean operators in filters) so you may want to keep some configuration snippets in their original form. This type lets you write texts into the configuration without any parsing or processing.

Every configuration file begins with a @version: <version> line. You can use this type to write this line into the configuration, make comments or use existing snippets.

```puppet
syslog_ng::config {'version':
   content => '@version: 3.6',
   order => '02'
}
```

#### Parameters

The following parameters are available in the `syslog_ng::config` defined type:

* [`content`](#-syslog_ng--config--content)
* [`order`](#-syslog_ng--config--order)

##### <a name="-syslog_ng--config--content"></a>`content`

Data type: `String[1]`

Configures the text which must be written into the configuration file. A newline character is automatically appended to its end.

##### <a name="-syslog_ng--config--order"></a>`order`

Data type: `String[1]`

Sets the order of this snippet in the configuration file. If you want to write the version line, the `order => '02'` is suggested, because the auto generated header has order '01'.

Default value: `'5'`

### <a name="syslog_ng--destination"></a>`syslog_ng::destination`

Creates a destination in your configuration.

```puppet
syslog_ng::destination { 'd_udp':
  params => {
    'type' => 'udp',
    'options' => [
      "'127.0.0.1'",
      { 'port' => '1999' },
      { 'localport' => '999' },
    ],
  },
}

#### Parameters

The following parameters are available in the `syslog_ng::destination` defined type:

* [`params`](#-syslog_ng--destination--params)

##### <a name="-syslog_ng--destination--params"></a>`params`

Data type: `Data`

An array of hashes or a single hash.

Default value: `[]`

### <a name="syslog_ng--filter"></a>`syslog_ng::filter`

Creates a filter in your configuration. **It does not support binary operators, such as `and` or `or`**. Please, use a `syslog_ng::config` if you need this functionality.

```puppet
syslog_ng::filter { 'f_tag_filter':
  params => {
    'type' => 'tags',
    'options' => [
      '".classifier.system"',
    ],
  },
}
```

#### Parameters

The following parameters are available in the `syslog_ng::filter` defined type:

* [`params`](#-syslog_ng--filter--params)

##### <a name="-syslog_ng--filter--params"></a>`params`

Data type: `Data`

An array of hashes or a single hash.

Default value: `[]`

### <a name="syslog_ng--log"></a>`syslog_ng::log`

Creates log paths in your configuration. It can create channels, junctions and reference already defined sources, destinations, etc. The syntax is a little bit different then the one previously described under statements.

Here is a simple rule: if you want to reference an already defined type (e.g. s_gsoc2014) use a hash with one key-value pair. The key must be the type of the statement (e.g. source) and the value must be its title.

If you do not specify a reference, use an array instead. Take a look at the example below:

```puppet
syslog_ng::log { 'l2':
  params => [
    { 'source' => 's_gsoc2014' },
    {
      'junction' => [
        {
          'channel' => [
            { 'filter' => 'f_json' },
            { 'parser' => 'p_json' },
          ],
        },
        {
          'channel' => [
            { 'filter' => 'f_not_json' },
            { 'flags' => 'final' },
          ],
        },
      ],
    },
    { 'destination' => 'd_gsoc' },
  ],
}
```

#### Parameters

The following parameters are available in the `syslog_ng::log` defined type:

* [`params`](#-syslog_ng--log--params)

##### <a name="-syslog_ng--log--params"></a>`params`

Data type: `Data`

The syntax is a bit different, but you can find examples under the tests directory.

Default value: `[]`

### <a name="syslog_ng--module"></a>`syslog_ng::module`

Install syslog-ng modules

### <a name="syslog_ng--options"></a>`syslog_ng::options`

Creates a global options statement. Currently it is not a class, so you should not declare it multiple times! It is not defined as a class, so you can declare it as other similar types.

```puppet
syslog_ng::options { "global_options":
  options => {
    'bad_hostname' => "'no'",
    'time_reopen'  => 10,
  },
}
```

#### Parameters

The following parameters are available in the `syslog_ng::options` defined type:

* [`options`](#-syslog_ng--options--options)

##### <a name="-syslog_ng--options--options"></a>`options`

Data type: `Hash`

A hash containing string keys and string values. In the generated configuration the keys will appear in alphabetical order.

Default value: `{}`

### <a name="syslog_ng--parser"></a>`syslog_ng::parser`

Creates a parser statement in your configuration.

```puppet
syslog_ng::parser { 'p_hostname_segmentation':
  params => {
    'type' => 'csv-parser',
    'options' => [
      {
        'columns' => [
          '"HOSTNAME.NAME"',
          '"HOSTNAME.ID"',
        ],
      },
      {'delimiters' => '"-"'},
      {'flags' => 'escape-none'},
      {'template' => '"${HOST}"'},
    ],
  },
}
```

#### Parameters

The following parameters are available in the `syslog_ng::parser` defined type:

* [`params`](#-syslog_ng--parser--params)

##### <a name="-syslog_ng--parser--params"></a>`params`

Data type: `Data`

An array of hashes or a single hash.

Default value: `[]`

### <a name="syslog_ng--rewrite"></a>`syslog_ng::rewrite`

Creates one or more rewrite rules in your configuration.

```puppet
syslog_ng::rewrite{ 'r_rewrite_subst':
  params => {
    'type' => 'subst',
    'options' => [
      '"IP"',
      '"IP-Address"',
      { 'value' => '"MESSAGE"' },
      { 'flags' => 'global' },
    ],
  },
}
```

#### Parameters

The following parameters are available in the `syslog_ng::rewrite` defined type:

* [`params`](#-syslog_ng--rewrite--params)

##### <a name="-syslog_ng--rewrite--params"></a>`params`

Data type: `Data`

An array of hashes or a single hash.

Default value: `[]`

### <a name="syslog_ng--source"></a>`syslog_ng::source`

Creates a source in your configuration.

```puppet
syslog_ng::source { 's_gsoc':
  params => {
    'type'    => 'tcp',
    'options' => [
      { 'ip' => "'127.0.0.1'" },
      { 'port' => 1999 },
    ],
  },
}

syslog_ng::source { 's_external':
  params => [
    {
      'type'    => 'udp',
      'options' => [
        { 'ip' => ["'127.0.0.1'"] },
        { 'port' => [514] },
      ],
    },
    {
      'type'    => 'tcp',
      'options' => [
        { 'ip' => ["'127.0.0.1'"] },
        { 'port' => [514] },
      ],
    },
    {
      'type'    => 'syslog',
      'options' => [
        { 'flags' => ['no-multi-line', 'no-parse'] },
        { 'ip' => ["'127.0.0.1'"] },
        { 'keep-alive' => ['yes'] },
        { 'keep_hostname' => ['yes'] },
        { 'transport' => ['udp'] },
      ],
    },
  ],
}
```

#### Parameters

The following parameters are available in the `syslog_ng::source` defined type:

* [`params`](#-syslog_ng--source--params)

##### <a name="-syslog_ng--source--params"></a>`params`

Data type: `Data`

An array of hashes or a single hash.

Default value: `[]`

### <a name="syslog_ng--template"></a>`syslog_ng::template`

Creates one or more templates in your configuration.

```puppet
syslog_ng::template {'t_demo_filetemplate':
  params => [
    {
      'type'    => 'template',
      'options' => [
        '"$ISODATE $HOST $MSG\n"',
      ],
    },
    {
      'type'    => 'template_escape',
      'options' => [
        'no',
      ],
    },
  ],
}
```

#### Parameters

The following parameters are available in the `syslog_ng::template` defined type:

* [`params`](#-syslog_ng--template--params)

##### <a name="-syslog_ng--template--params"></a>`params`

Data type: `Data`

An array of hashes or a single hash.

Default value: `[]`

## Functions

### <a name="syslog_ng--generate_log"></a>`syslog_ng::generate_log`

Type: Ruby 4.x API

Gererate log

#### `syslog_ng::generate_log(Data $options)`

Gererate log

Returns: `String` The generated log

##### `options`

Data type: `Data`



### <a name="syslog_ng--generate_options"></a>`syslog_ng::generate_options`

Type: Ruby 4.x API

Generate options

#### `syslog_ng::generate_options(Hash[String[1], Variant[Integer, String]] $options)`

Generate options

Returns: `String` The generated options

##### `options`

Data type: `Hash[String[1], Variant[Integer, String]]`



### <a name="syslog_ng--generate_statement"></a>`syslog_ng::generate_statement`

Type: Ruby 4.x API

Generate statement

#### `syslog_ng::generate_statement(String $id, String $type, Data $params)`

Generate statement

Returns: `String` The generated statement

##### `id`

Data type: `String`



##### `type`

Data type: `String`



##### `params`

Data type: `Data`



